#[repr(transparent)]pub struct Misc2(pub u32);Expand description
Miscellaneous Register 2
Tuple Fields
0: u32Implementations
Sourceimpl Misc2
impl Misc2
Sourcepub const fn reg0_bo_offset(&self) -> Misc2Reg0BoOffset
pub const fn reg0_bo_offset(&self) -> Misc2Reg0BoOffset
This field defines the brown out voltage offset for the CORE power domain
Sourcepub const fn set_reg0_bo_offset(&mut self, val: Misc2Reg0BoOffset)
pub const fn set_reg0_bo_offset(&mut self, val: Misc2Reg0BoOffset)
This field defines the brown out voltage offset for the CORE power domain
Sourcepub const fn reg0_bo_status(&self) -> bool
pub const fn reg0_bo_status(&self) -> bool
Reg0 brownout status bit.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg0_bo_status(&mut self, val: bool)
pub const fn set_reg0_bo_status(&mut self, val: bool)
Reg0 brownout status bit.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg0_enable_bo(&self) -> bool
pub const fn reg0_enable_bo(&self) -> bool
Enables the brownout detection.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg0_enable_bo(&mut self, val: bool)
pub const fn set_reg0_enable_bo(&mut self, val: bool)
Enables the brownout detection.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg0_ok(&self) -> bool
pub const fn reg0_ok(&self) -> bool
Arm supply Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg0_ok(&mut self, val: bool)
pub const fn set_reg0_ok(&mut self, val: bool)
Arm supply Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn pll3_disable(&self) -> Misc2Pll3Disable
pub const fn pll3_disable(&self) -> Misc2Pll3Disable
When USB is in low power suspend mode this Control bit is used to indicate if other system peripherals require the USB PLL3 clock when the SoC is not in low power mode
Sourcepub const fn set_pll3_disable(&mut self, val: Misc2Pll3Disable)
pub const fn set_pll3_disable(&mut self, val: Misc2Pll3Disable)
When USB is in low power suspend mode this Control bit is used to indicate if other system peripherals require the USB PLL3 clock when the SoC is not in low power mode
Sourcepub const fn reg1_bo_offset(&self) -> Misc2Reg1BoOffset
pub const fn reg1_bo_offset(&self) -> Misc2Reg1BoOffset
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn set_reg1_bo_offset(&mut self, val: Misc2Reg1BoOffset)
pub const fn set_reg1_bo_offset(&mut self, val: Misc2Reg1BoOffset)
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn reg1_bo_status(&self) -> bool
pub const fn reg1_bo_status(&self) -> bool
Reg1 brownout status bit. Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg1_bo_status(&mut self, val: bool)
pub const fn set_reg1_bo_status(&mut self, val: bool)
Reg1 brownout status bit. Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg1_enable_bo(&self) -> bool
pub const fn reg1_enable_bo(&self) -> bool
Enables the brownout detection.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg1_enable_bo(&mut self, val: bool)
pub const fn set_reg1_enable_bo(&mut self, val: bool)
Enables the brownout detection.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg1_ok(&self) -> bool
pub const fn reg1_ok(&self) -> bool
GPU supply Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg1_ok(&mut self, val: bool)
pub const fn set_reg1_ok(&mut self, val: bool)
GPU supply Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn audio_div_lsb(&self) -> Misc2AudioDivLsb
pub const fn audio_div_lsb(&self) -> Misc2AudioDivLsb
LSB of Post-divider for Audio PLL
Sourcepub const fn set_audio_div_lsb(&mut self, val: Misc2AudioDivLsb)
pub const fn set_audio_div_lsb(&mut self, val: Misc2AudioDivLsb)
LSB of Post-divider for Audio PLL
Sourcepub const fn reg2_bo_offset(&self) -> Misc2Reg2BoOffset
pub const fn reg2_bo_offset(&self) -> Misc2Reg2BoOffset
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn set_reg2_bo_offset(&mut self, val: Misc2Reg2BoOffset)
pub const fn set_reg2_bo_offset(&mut self, val: Misc2Reg2BoOffset)
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn reg2_bo_status(&self) -> bool
pub const fn reg2_bo_status(&self) -> bool
Reg2 brownout status bit.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg2_bo_status(&mut self, val: bool)
pub const fn set_reg2_bo_status(&mut self, val: bool)
Reg2 brownout status bit.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg2_enable_bo(&self) -> bool
pub const fn reg2_enable_bo(&self) -> bool
Enables the brownout detection.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg2_enable_bo(&mut self, val: bool)
pub const fn set_reg2_enable_bo(&mut self, val: bool)
Enables the brownout detection.Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg2_ok(&self) -> bool
pub const fn reg2_ok(&self) -> bool
Signals that the voltage is above the brownout level for the SOC supply
Sourcepub const fn set_reg2_ok(&mut self, val: bool)
pub const fn set_reg2_ok(&mut self, val: bool)
Signals that the voltage is above the brownout level for the SOC supply
Sourcepub const fn audio_div_msb(&self) -> Misc2AudioDivMsb
pub const fn audio_div_msb(&self) -> Misc2AudioDivMsb
MSB of Post-divider for Audio PLL
Sourcepub const fn set_audio_div_msb(&mut self, val: Misc2AudioDivMsb)
pub const fn set_audio_div_msb(&mut self, val: Misc2AudioDivMsb)
MSB of Post-divider for Audio PLL
Sourcepub const fn reg0_step_time(&self) -> Misc2Reg0StepTime
pub const fn reg0_step_time(&self) -> Misc2Reg0StepTime
Number of clock periods (24MHz clock).Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg0_step_time(&mut self, val: Misc2Reg0StepTime)
pub const fn set_reg0_step_time(&mut self, val: Misc2Reg0StepTime)
Number of clock periods (24MHz clock).Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg1_step_time(&self) -> Misc2Reg1StepTime
pub const fn reg1_step_time(&self) -> Misc2Reg1StepTime
Number of clock periods (24MHz clock).Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg1_step_time(&mut self, val: Misc2Reg1StepTime)
pub const fn set_reg1_step_time(&mut self, val: Misc2Reg1StepTime)
Number of clock periods (24MHz clock).Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn reg2_step_time(&self) -> Misc2Reg2StepTime
pub const fn reg2_step_time(&self) -> Misc2Reg2StepTime
Number of clock periods (24MHz clock).Not related to CCM. See Power Management Unit (PMU)
Sourcepub const fn set_reg2_step_time(&mut self, val: Misc2Reg2StepTime)
pub const fn set_reg2_step_time(&mut self, val: Misc2Reg2StepTime)
Number of clock periods (24MHz clock).Not related to CCM. See Power Management Unit (PMU)