nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Pfd480Clr

Struct Pfd480Clr 

#[repr(transparent)]
pub struct Pfd480Clr(pub u32);
480MHz Clock (PLL3) Phase Fractional Divider Control Register

Tuple Fields

0: u32

Implementations

Source

impl Pfd480Clr

pub const fn pfd0_frac(&self) -> u8

This field controls the fractional divide value

pub const fn set_pfd0_frac(&mut self, val: u8)

This field controls the fractional divide value

pub const fn pfd0_stable(&self) -> bool

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn set_pfd0_stable(&mut self, val: bool)

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn pfd0_clkgate(&self) -> bool

If set to 1, the IO fractional divider clock (reference ref_pfd0) is off (power savings)

pub const fn set_pfd0_clkgate(&mut self, val: bool)

If set to 1, the IO fractional divider clock (reference ref_pfd0) is off (power savings)

pub const fn pfd1_frac(&self) -> u8

This field controls the fractional divide value

pub const fn set_pfd1_frac(&mut self, val: u8)

This field controls the fractional divide value

pub const fn pfd1_stable(&self) -> bool

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn set_pfd1_stable(&mut self, val: bool)

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn pfd1_clkgate(&self) -> bool

IO Clock Gate

pub const fn set_pfd1_clkgate(&mut self, val: bool)

IO Clock Gate

pub const fn pfd2_frac(&self) -> u8

This field controls the fractional divide value

pub const fn set_pfd2_frac(&mut self, val: u8)

This field controls the fractional divide value

pub const fn pfd2_stable(&self) -> bool

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn set_pfd2_stable(&mut self, val: bool)

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn pfd2_clkgate(&self) -> bool

IO Clock Gate

pub const fn set_pfd2_clkgate(&mut self, val: bool)

IO Clock Gate

pub const fn pfd3_frac(&self) -> u8

This field controls the fractional divide value

pub const fn set_pfd3_frac(&mut self, val: u8)

This field controls the fractional divide value

pub const fn pfd3_stable(&self) -> bool

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn set_pfd3_stable(&mut self, val: bool)

This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional divider should become stable quickly enough that this field will never need to be used by either device driver or application code

pub const fn pfd3_clkgate(&self) -> bool

IO Clock Gate

pub const fn set_pfd3_clkgate(&mut self, val: bool)

IO Clock Gate